+++
title = "PyPipegraph2 documentation"
+++

Welcome to the PyPipegraph2 (ppg2) documentation.

We strive for [Diátaxis](https://idratherbewriting.com/blog/what-is-diataxis-documentation-framework) in our documentation,
therefore this documentation is structured into

* [Tutorial](#tutorials)
* [How-Tos](#how-tos)
* [Reference](#reference)
* [Explanations](#explanations)
* [FAQ](./faq)



## Tutorials

* Minimal getting started
* A larger example


## How-Tos

* Patterns for structuring job creations
* Common 'gotchas'

## Reference

* Job classes
* Managing Pypipegraphs
* handy utilities


## Explanations

* Concepts and considerations



